@@ -69,8 +69,7 @@ QSharedPointer<DkMetaDataT> DkMetaDataT::copy() const
         // ImageFactory::create(type) may crash even if old Image object has that type
         try {
             // Load new Exiv2::Image object
-            int i_type = mExifImg->imageType();
-            metaDataN->mExifImg = Exiv2::ImageFactory::create(i_type);
+            metaDataN->mExifImg = Exiv2::ImageFactory::create(mExifImg->imageType());
             // Copy exif data from old object into new object
             Exiv2::ExifData data = mExifImg->exifData();
             metaDataN->mExifImg->setExifData(data); // explicit copy of list<Exifdatum>
@@ -92,6 +91,8 @@ void DkMetaDataT::update(const QSharedPointer<DkMetaDataT> &other)
 {
     QSharedPointer<DkMetaDataT> src(other);
     // Copy exif data (to this instance), reading from src
+    if (src->isNull())
+        return;
     mExifImg->setExifData(src->mExifImg->exifData()); // explicit copy of list<Exifdatum>
 }
 
@@ -114,8 +115,7 @@ void DkMetaDataT::readMetaData(const QString &filePath, QSharedPointer<QByteArra
             std::string strFilePath = (fileInfo.isSymLink()) ? fileInfo.symLinkTarget().toStdString() : filePath.toStdString();
             mExifImg = Exiv2::ImageFactory::open(strFilePath);
         } else {
-            Exiv2::BasicIo::AutoPtr exifBuffer(new Exiv2::MemIo((const byte *)ba->constData(), ba->size()));
-            mExifImg = Exiv2::ImageFactory::open(exifBuffer);
+            mExifImg = Exiv2::ImageFactory::open(reinterpret_cast<const byte *>(ba->constData()), ba->size());
         }
     } catch (...) {
         // TODO: check crashes here
@@ -217,13 +217,11 @@ bool DkMetaDataT::saveMetaData(QSharedPointer<QByteArray> &ba, bool force)
     Exiv2::XmpData &xmpData = mExifImg->xmpData();
     Exiv2::IptcData &iptcData = mExifImg->iptcData();
 
-    Exiv2::Image::AutoPtr exifImgN;
-    Exiv2::MemIo::AutoPtr exifMem;
+    std::unique_ptr<Exiv2::Image> exifImgN;
 
     try {
         // Load new exif object (based on byte array of raw image file, see overload)
-        exifMem = Exiv2::MemIo::AutoPtr(new Exiv2::MemIo((byte *)ba->data(), ba->size()));
-        exifImgN = Exiv2::ImageFactory::open(exifMem);
+        exifImgN = Exiv2::ImageFactory::open(reinterpret_cast<const byte *>(ba->constData()), ba->size());
     } catch (...) {
         qDebug() << "could not open image for exif data";
         return false;
@@ -246,9 +244,13 @@ bool DkMetaDataT::saveMetaData(QSharedPointer<QByteArray> &ba, bool force)
     // Copy image + new exif and return temporary object as byte array
     // The calling function should then write it back to the file
     Exiv2::DataBuf exifBuf = exifImgN->io().read((long)exifImgN->io().size());
+#if EXIV2_TEST_VERSION(0, 28, 0)
+    if (!exifBuf.empty()) {
+        QSharedPointer<QByteArray> tmp = QSharedPointer<QByteArray>(new QByteArray(reinterpret_cast<const char *>(exifBuf.c_data()), exifBuf.size()));
+#else
     if (exifBuf.pData_) {
-        QSharedPointer<QByteArray> tmp = QSharedPointer<QByteArray>(new QByteArray((const char *)exifBuf.pData_, exifBuf.size_));
-
+        QSharedPointer<QByteArray> tmp = QSharedPointer<QByteArray>(new QByteArray(reinterpret_cast<const char *>(exifBuf.pData_), exifBuf.size_));
+#endif
         if (tmp->size() > qRound(ba->size() * 0.5f))
             ba = tmp;
         else
@@ -257,7 +259,7 @@ bool DkMetaDataT::saveMetaData(QSharedPointer<QByteArray> &ba, bool force)
         return false;
 
     // Replace old exif object with new one and clear "dirty" flag
-    mExifImg = exifImgN;
+    mExifImg.swap(exifImgN);
     mExifState = loaded;
 
     return true;
@@ -304,7 +306,7 @@ int DkMetaDataT::getOrientationDegree() const
             Exiv2::ExifData::iterator pos = exifData.findKey(key);
 
             if (pos != exifData.end() && pos->count() != 0) {
-                Exiv2::Value::AutoPtr v = pos->getValue();
+                auto v = pos->getValue();
                 orientation = (int)pos->toFloat();
 
                 switch (orientation) {
@@ -384,7 +386,7 @@ int DkMetaDataT::getRating() const
         Exiv2::ExifData::iterator pos = exifData.findKey(key);
 
         if (pos != exifData.end() && pos->count() != 0) {
-            Exiv2::Value::AutoPtr v = pos->getValue();
+            auto v = pos->getValue();
             exifRating = v->toFloat();
         }
     }
@@ -396,7 +398,7 @@ int DkMetaDataT::getRating() const
 
         // xmp Rating tag
         if (pos != xmpData.end() && pos->count() != 0) {
-            Exiv2::Value::AutoPtr v = pos->getValue();
+            auto v = pos->getValue();
             xmpRating = v->toFloat();
         }
 
@@ -405,7 +407,7 @@ int DkMetaDataT::getRating() const
             key = Exiv2::XmpKey("Xmp.MicrosoftPhoto.Rating");
             pos = xmpData.findKey(key);
             if (pos != xmpData.end() && pos->count() != 0) {
-                Exiv2::Value::AutoPtr v = pos->getValue();
+                auto v = pos->getValue();
                 xmpRating = v->toFloat();
             }
         }
@@ -505,7 +507,7 @@ QString DkMetaDataT::getXmpValue(const QString &key) const
         }
 
         if (pos != xmpData.end() && pos->count() != 0) {
-            Exiv2::Value::AutoPtr v = pos->getValue();
+            auto v = pos->getValue();
             info = exiv2ToQString(pos->toString());
         }
     }
@@ -573,7 +575,7 @@ QString DkMetaDataT::getIptcValue(const QString &key) const
         }
 
         if (pos != iptcData.end() && pos->count() != 0) {
-            Exiv2::Value::AutoPtr v = pos->getValue();
+            auto v = pos->getValue();
             info = exiv2ToQString(pos->toString());
         }
     }
@@ -715,7 +717,11 @@ QImage DkMetaDataT::getThumbnail() const
         Exiv2::ExifThumb thumb(exifData);
         Exiv2::DataBuf buffer = thumb.copy();
 
-        QByteArray ba = QByteArray((char *)buffer.pData_, buffer.size_);
+#if EXIV2_TEST_VERSION(0, 28, 0)
+        QByteArray ba = QByteArray(reinterpret_cast<const char *>(buffer.c_data()), buffer.size());
+#else
+        QByteArray ba = QByteArray(reinterpret_cast<const char *>(buffer.pData_), buffer.size_);
+#endif
         qThumb.loadFromData(ba);
     } catch (...) {
         qDebug() << "Sorry, I could not load the thumb from the exif data...";
@@ -994,8 +1000,7 @@ void DkMetaDataT::setThumbnail(QImage thumb)
 
         try {
             // whipe all exif data of the thumbnail
-            Exiv2::MemIo::AutoPtr exifBufferThumb(new Exiv2::MemIo((const byte *)ba.constData(), ba.size()));
-            Exiv2::Image::AutoPtr exifImgThumb = Exiv2::ImageFactory::open(exifBufferThumb);
+            auto exifImgThumb = Exiv2::ImageFactory::open(reinterpret_cast<const byte *>(ba.constData()), ba.size());
 
             if (exifImgThumb.get() != 0 && exifImgThumb->good())
                 exifImgThumb->clearExifData();
@@ -1106,12 +1111,12 @@ void DkMetaDataT::setOrientation(int o)
         pos = exifData.findKey(key);
     }
 
-    Exiv2::Value::AutoPtr v = pos->getValue();
+    auto v = pos->getValue();
     Exiv2::UShortValue *prv = dynamic_cast<Exiv2::UShortValue *>(v.release());
     if (!prv)
         return;
 
-    Exiv2::UShortValue::AutoPtr rv = Exiv2::UShortValue::AutoPtr(prv);
+    std::unique_ptr<Exiv2::UShortValue> rv(prv);
     if (rv->value_.empty())
         return;
 
@@ -1202,7 +1207,7 @@ void DkMetaDataT::setRating(int r)
         exifData["Exif.Image.Rating"] = uint16_t(r);
         exifData["Exif.Image.RatingPercent"] = uint16_t(r);
 
-        Exiv2::Value::AutoPtr v = Exiv2::Value::create(Exiv2::xmpText);
+        auto v = Exiv2::Value::create(Exiv2::xmpText);
         v->read(sRating);
         xmpData.add(Exiv2::XmpKey("Xmp.xmp.Rating"), v.get());
         v->read(sRatingPercent);
@@ -1448,9 +1453,9 @@ DkRotatingRect DkMetaDataT::getXMPRect(const QSize &size) const
     return DkRotatingRect(rr);
 }
 
-Exiv2::Image::AutoPtr DkMetaDataT::loadSidecar(const QString &filePath) const
+std::unique_ptr<Exiv2::Image> DkMetaDataT::loadSidecar(const QString &filePath) const
 {
-    Exiv2::Image::AutoPtr xmpImg;
+    std::unique_ptr<Exiv2::Image> xmpImg;
 
     // TODO: check if the file type supports xmp
 
@@ -1500,7 +1505,7 @@ bool DkMetaDataT::setXMPValue(Exiv2::XmpData &xmpData, QString xmpKey, QString x
         if (!pos->setValue(xmpValue.toStdString()))
             setXMPValueSuccessful = true;
     } else {
-        Exiv2::Value::AutoPtr v = Exiv2::Value::create(Exiv2::xmpText);
+        auto v = Exiv2::Value::create(Exiv2::xmpText);
         if (!v->read(xmpValue.toStdString())) {
             if (!xmpData.add(Exiv2::XmpKey(key), v.get()))
                 setXMPValueSuccessful = true;
