@@ -409,6 +409,11 @@ void DkGeneralPreference::createLayout()
     cbCloseOnEsc->setToolTip(tr("Close nomacs if ESC is pressed."));
     cbCloseOnEsc->setChecked(DkSettingsManager::param().app().closeOnEsc);
 
+    QCheckBox *cbCloseOnMiddleMouse = new QCheckBox(tr("Close on Middle Mouse Button"), this);
+    cbCloseOnMiddleMouse->setObjectName("closeOnMiddleMouse");
+    cbCloseOnMiddleMouse->setToolTip(tr("Close nomacs if the Middle Mouse Button is pressed over the image."));
+    cbCloseOnMiddleMouse->setChecked(DkSettingsManager::param().app().closeOnMiddleMouse);
+
     QCheckBox *cbCheckForUpdates = new QCheckBox(tr("Check For Updates"), this);
     cbCheckForUpdates->setObjectName("checkForUpdates");
     cbCheckForUpdates->setToolTip(tr("Check for updates on start-up."));
@@ -426,6 +431,7 @@ void DkGeneralPreference::createLayout()
     generalGroup->addWidget(cbDoubleClickForFullscreen);
     generalGroup->addWidget(cbSwitchModifier);
     generalGroup->addWidget(cbCloseOnEsc);
+    generalGroup->addWidget(cbCloseOnMiddleMouse);
     generalGroup->addWidget(cbCheckForUpdates);
     generalGroup->addWidget(cbShowBgImage);
 
@@ -529,6 +535,12 @@ void DkGeneralPreference::on_closeOnEsc_toggled(bool checked) const
         DkSettingsManager::param().app().closeOnEsc = checked;
 }
 
+void DkGeneralPreference::on_closeOnMiddleMouse_toggled(bool checked) const
+{
+    if (DkSettingsManager::param().app().closeOnMiddleMouse != checked)
+        DkSettingsManager::param().app().closeOnMiddleMouse = checked;
+}
+
 void DkGeneralPreference::on_zoomOnWheel_toggled(bool checked) const
 {
     if (DkSettingsManager::param().global().zoomOnWheel != checked) {
@@ -1483,8 +1495,10 @@ void DkAdvancedPreference::on_useNative_toggled(bool checked) const
 void DkAdvancedPreference::on_logFolder_clicked() const
 {
     // TODO: add linux/mac os
+#ifdef _WIN32
     QString logPath = QDir::toNativeSeparators(DkUtils::getLogFilePath());
     QProcess::startDetached(QString("explorer /select, \"%1\"").arg(logPath));
+#endif
 }
 
 void DkAdvancedPreference::on_numThreads_valueChanged(int val) const
